@@ -22,7 +22,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_sctc_filter.cpp,v 1.7 2005/05/28 13:54:57 suzhe Exp $
+ * $Id: scim_sctc_filter.cpp,v 1.7.2.1 2006/01/09 13:37:25 suzhe Exp $
  *
  */
 
@@ -103,30 +103,13 @@ extern "C" {
     void scim_module_init (void)
     {
         //Initialize encoding information.
-        std::vector <String> locales;
-        String encoding;
-        size_t i;
-
-        scim_split_string_list (locales, scim_get_language_locales ("zh_CN"));
-        for (i = 0; i < locales.size (); ++i) {
-            encoding = scim_get_locale_encoding (locales [i]);
-            if (encoding != "UTF-8" && !__is_sc_encoding (encoding))
-                __sc_encodings.push_back (encoding);
-        }
-
-        scim_split_string_list (locales, scim_get_language_locales ("zh_TW"));
-        for (i = 0; i < locales.size (); ++i) {
-            encoding = scim_get_locale_encoding (locales [i]);
-            if (encoding != "UTF-8" && !__is_tc_encoding (encoding))
-                __tc_encodings.push_back (encoding);
-        }
-
-        scim_split_string_list (locales, scim_get_language_locales ("zh_HK"));
-        for (i = 0; i < locales.size (); ++i) {
-            encoding = scim_get_locale_encoding (locales [i]);
-            if (encoding != "UTF-8" && !__is_tc_encoding (encoding))
-                __tc_encodings.push_back (encoding);
-        }
+        __sc_encodings.push_back ("GB2312");
+        __sc_encodings.push_back ("GBK");
+        __sc_encodings.push_back ("GB18030");
+        __sc_encodings.push_back ("EUC-CN");
+        __tc_encodings.push_back ("BIG5");
+        __tc_encodings.push_back ("BIG5-HKSCS");
+        __tc_encodings.push_back ("EUC-TW");
     }
 
     void scim_module_exit (void)
@@ -135,10 +118,7 @@ extern "C" {
 
     unsigned int scim_filter_module_init (const ConfigPointer &config)
     {
-        if (__sc_encodings.size () || __tc_encodings.size ())
-            return 1;
-
-        return 0;
+        return 1;
     }
 
     FilterFactoryPointer scim_filter_module_create_filter (unsigned int index)
