@@ -6,7 +6,7 @@
 /* 
  * Smart Common Input Method
  * 
- * Copyright (c) 2002 James Su <suzhe@turbolinux.com.cn>
+ * Copyright (c) 2002-2005 James Su <suzhe@tsinghua.org.cn>
  *
  *
  * This library is free software; you can redistribute it and/or
@@ -24,12 +24,14 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_socket_frontend.h,v 1.18 2004/07/23 16:17:30 suzhe Exp $
+ * $Id: scim_socket_frontend.h,v 1.26 2005/04/14 17:01:56 suzhe Exp $
  */
 
 #if !defined (__SCIM_SOCKET_FRONTEND_H)
 #define __SCIM_SOCKET_FRONTEND_H
 
+#include "scim_stl_map.h"
+
 using namespace scim;
 
 class SocketFrontEnd : public FrontEndBase
@@ -50,17 +52,21 @@ class SocketFrontEnd : public FrontEndBase
      */
     typedef std::vector <std::pair <int, int> > SocketInstanceRepository;
 
-    /**
-     * ::first = socket id, ::second = auth key.
-     */
-    typedef std::map<int, ClientInfo> SocketClientRepository;
+#if SCIM_USE_STL_EXT_HASH_MAP
+    typedef __gnu_cxx::hash_map <int, ClientInfo, __gnu_cxx::hash <int> >   SocketClientRepository;
+#elif SCIM_USE_STL_HASH_MAP
+    typedef std::hash_map <int, ClientInfo, std::hash <int> >               SocketClientRepository;
+#else
+    typedef std::map <int, ClientInfo>                                      SocketClientRepository;
+#endif
 
     ConfigPointer     m_config;
 
     SocketServer      m_socket_server;
 
-    SocketTransaction m_send_transaction;
-    SocketTransaction m_receive_transaction;
+    Transaction       m_send_trans;
+    Transaction       m_receive_trans;
+    Transaction       m_temp_trans;
 
     SocketInstanceRepository m_socket_instance_repository;
 
@@ -74,6 +80,10 @@ class SocketFrontEnd : public FrontEndBase
 
     int    m_current_instance;
 
+    int    m_current_socket_client;
+
+    uint32 m_current_socket_client_key;
+
 public:
     SocketFrontEnd (const BackEndPointer &backend,
                     const ConfigPointer  &config);
@@ -81,23 +91,32 @@ public:
     virtual ~SocketFrontEnd ();
 
 protected:
-    virtual void show_preedit_string   (int id);
-    virtual void show_aux_string       (int id);
-    virtual void show_lookup_table     (int id);
+    virtual void show_preedit_string     (int id);
+    virtual void show_aux_string         (int id);
+    virtual void show_lookup_table       (int id);
 
-    virtual void hide_preedit_string   (int id);
-    virtual void hide_aux_string       (int id);
-    virtual void hide_lookup_table     (int id);
+    virtual void hide_preedit_string     (int id);
+    virtual void hide_aux_string         (int id);
+    virtual void hide_lookup_table       (int id);
 
-    virtual void update_preedit_caret  (int id, int caret);
-    virtual void update_preedit_string (int id, const WideString & str, const AttributeList & attrs);
-    virtual void update_aux_string     (int id, const WideString & str, const AttributeList & attrs);
-    virtual void commit_string         (int id, const WideString & str);
-    virtual void forward_key_event     (int id, const KeyEvent & key);
-    virtual void update_lookup_table   (int id, const LookupTable & table);
+    virtual void update_preedit_caret    (int id, int caret);
+    virtual void update_preedit_string   (int id, const WideString & str, const AttributeList & attrs);
+    virtual void update_aux_string       (int id, const WideString & str, const AttributeList & attrs);
+    virtual void commit_string           (int id, const WideString & str);
+    virtual void forward_key_event       (int id, const KeyEvent & key);
+    virtual void update_lookup_table     (int id, const LookupTable & table);
 
-    virtual void register_properties   (int id, const PropertyList & properties);
-    virtual void update_property       (int id, const Property & property);
+    virtual void register_properties     (int id, const PropertyList & properties);
+    virtual void update_property         (int id, const Property & property);
+
+    virtual void beep                    (int id);
+
+    virtual void start_helper            (int id, const String &helper_uuid);
+    virtual void stop_helper             (int id, const String &helper_uuid);
+    virtual void send_helper_event       (int id, const String &helper_uuid, const Transaction &trans);
+
+    virtual bool get_surrounding_text    (int id, WideString &text, int &cursor, int maxlen_before, int maxlen_after);
+    virtual bool delete_surrounding_text (int id, int offset, int len);
 
 public:
     virtual void init (int argc, char **argv);
@@ -140,6 +159,8 @@ private:
     void socket_focus_in                    (int client_id);
     void socket_focus_out                   (int client_id);
     void socket_trigger_property            (int client_id);
+    void socket_process_helper_event        (int client_id);
+    void socket_update_client_capabilities  (int client_id);
 
     void socket_flush_config                (int client_id);
     void socket_erase_config                (int client_id);
