@@ -6,9 +6,7 @@
 /* 
  * Smart Common Input Method
  * 
- * Copyright (c) 2004 James Su <suzhe@turbolinux.com.cn>
- * Copyright (c) 2003 James Su <suzhe@turbolinux.com.cn>
- * Copyright (c) 2002 James Su <suzhe@turbolinux.com.cn>
+ * Copyright (c) 2002-2005 James Su <suzhe@tsinghua.org.cn>
  *
  *
  * This library is free software; you can redistribute it and/or
@@ -26,7 +24,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim.h,v 1.23 2004/07/20 10:33:53 suzhe Exp $
+ * $Id: scim.h,v 1.38 2005/05/17 06:45:14 suzhe Exp $
  */
 
 // Define the macros
@@ -46,20 +44,61 @@
 #define Uses_STL_ALGORITHM
 #define Uses_STL_NEW
 
-#ifdef Uses_SCIM_COMPOSE_KEY
+#ifdef Uses_SCIM_FILTER_MANAGER
+    #define Uses_SCIM_FILTER
+#endif
+
+#ifdef Uses_SCIM_FILTER_MODULE
+    #define Uses_SCIM_MODULE
+    #define Uses_SCIM_CONFIG_BASE
+    #define Uses_SCIM_BACKEND
+    #define Uses_SCIM_FILTER
+#endif
+
+#ifdef Uses_SCIM_FILTER
     #define Uses_SCIM_IMENGINE
 #endif
 
 #ifdef Uses_SCIM_PANEL
-    #define Uses_SCIM_SOCKET_TRANSACTION
+    #define Uses_SCIM_PANEL_AGENT
+    #define Uses_SCIM_PANEL_CLIENT
 #endif
 
-#ifdef Uses_SCIM_SOCKET_TRANSACTION
+#ifdef Uses_SCIM_PANEL_AGENT
+    #define Uses_SCIM_HELPER_MANAGER
+    #define Uses_SCIM_TRANSACTION
+#endif
+
+#ifdef Uses_SCIM_PANEL_CLIENT
+    #define Uses_SCIM_TRANSACTION
+#endif
+
+#ifdef Uses_SCIM_HELPER_MANAGER
+    #define Uses_SCIM_HELPER
+#endif
+
+#ifdef Uses_SCIM_HELPER_MODULE
+    #define Uses_SCIM_HELPER
+    #define Uses_SCIM_MODULE
+    #define Uses_SCIM_CONFIG_BASE
+#endif
+
+#ifdef Uses_SCIM_HELPER
+    #define Uses_SCIM_TRANSACTION
+    #define Uses_SCIM_EVENT
+#endif
+
+#ifdef Uses_SCIM_COMPOSE_KEY
+    #define Uses_SCIM_IMENGINE
+#endif
+
+#ifdef Uses_SCIM_TRANSACTION
     #define Uses_SCIM_EVENT
     #define Uses_SCIM_LOOKUP_TABLE
     #define Uses_SCIM_SOCKET
     #define Uses_SCIM_ATTRIBUTE
     #define Uses_SCIM_PROPERTY
+    #define Uses_SCIM_TRANS_COMMANDS
 #endif
 
 #ifdef Uses_SCIM_CONFIG_MODULE
@@ -92,6 +131,8 @@
     #define Uses_C_STDIO
     #define Uses_SCIM_ATTRIBUTE
     #define Uses_SCIM_PROPERTY
+    #define Uses_SCIM_TRANSACTION
+    #define Uses_SCIM_SOCKET
 #endif
 
 #ifdef Uses_SCIM_BACKEND
@@ -105,6 +146,8 @@
     #define Uses_SCIM_LOOKUP_TABLE
     #define Uses_SCIM_ATTRIBUTE
     #define Uses_SCIM_PROPERTY
+    #define Uses_SCIM_TRANSACTION
+    #define Uses_SCIM_SOCKET
 #endif
 
 #ifdef Uses_SCIM_LOOKUP_TABLE
@@ -131,6 +174,12 @@
     #define Uses_STL_IOSTREAM
 #endif
 
+#ifdef Uses_SCIM_HOTKEY
+    #define Uses_SCIM_EVENT
+    #define Uses_SCIM_CONFIG_BASE
+    #define Uses_SCIM_CONFIG_PATH
+#endif
+
 // Include Standard headers
 #ifdef Uses_STL_EXCEPTION
     #include <exception>
@@ -249,14 +298,14 @@
     #include <scim_global_config.h>
 #endif
 
-#ifdef Uses_SCIM_OBJECT
-    #include <scim_object.h>
-#endif
-
 #ifdef Uses_SCIM_POINTER
     #include <scim_pointer.h>
 #endif
 
+#ifdef Uses_SCIM_OBJECT
+    #include <scim_object.h>
+#endif
+
 #ifdef Uses_SCIM_SLOT
     #include <scim_slot.h>
 #endif
@@ -297,6 +346,14 @@
     #include <scim_module.h>
 #endif
 
+#ifdef Uses_SCIM_SOCKET
+    #include <scim_socket.h>
+#endif
+
+#ifdef Uses_SCIM_TRANSACTION
+    #include <scim_transaction.h>
+#endif
+
 #ifdef Uses_SCIM_IMENGINE
     #include <scim_imengine.h>
 #endif
@@ -329,18 +386,45 @@
     #include <scim_config_path.h>
 #endif
 
-#ifdef Uses_SCIM_SOCKET
-    #include <scim_socket.h>
+#ifdef Uses_SCIM_TRANS_COMMANDS
+    #include <scim_trans_commands.h>
 #endif
 
-#ifdef Uses_SCIM_SOCKET_TRANSACTION
-    #include <scim_socket_transaction.h>
+#ifdef Uses_SCIM_HELPER
+    #include <scim_helper.h>
 #endif
 
-#ifdef Uses_SCIM_PANEL
-    #include <scim_panel.h>
+#ifdef Uses_SCIM_HELPER_MODULE
+    #include <scim_helper_module.h>
 #endif
 
+#ifdef Uses_SCIM_HELPER_MANAGER
+    #include <scim_helper_manager.h>
+#endif
+
+#ifdef Uses_SCIM_PANEL_AGENT
+    #include <scim_panel_agent.h>
+#endif
+
+#ifdef Uses_SCIM_PANEL_CLIENT
+    #include <scim_panel_client.h>
+#endif
+
+#ifdef Uses_SCIM_HOTKEY
+    #include <scim_hotkey.h>
+#endif
+
+#ifdef Uses_SCIM_FILTER
+    #include <scim_filter.h>
+#endif
+
+#ifdef Uses_SCIM_FILTER_MODULE
+    #include <scim_filter_module.h>
+#endif
+
+#ifdef Uses_SCIM_FILTER_MANAGER
+    #include <scim_filter_manager.h>
+#endif
 /*
 vi:ts=4:nowrap:ai:expandtab
 */
