@@ -1,9 +1,7 @@
 /*
  * Smart Common Input Method
  * 
- * Copyright (c) 2004 James Su <suzhe@turbolinux.com.cn>
- * Copyright (c) 2003 James Su <suzhe@turbolinux.com.cn>
- * Copyright (c) 2002 James Su <suzhe@turbolinux.com.cn>
+ * Copyright (c) 2002-2005 James Su <suzhe@tsinghua.org.cn>
  *
  *
  * This library is free software; you can redistribute it and/or
@@ -21,13 +19,14 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_config_agent.cpp,v 1.4 2004/07/02 14:06:36 suzhe Exp $
+ * $Id: scim_config_agent.cpp,v 1.10 2005/07/03 08:36:42 suzhe Exp $
  *
  */
 
 #define Uses_STL_IOSTREAM
 #define Uses_C_LOCALE
 #define Uses_SCIM_CONFIG_MODULE
+#define Uses_SCIM_HELPER
 #define Uses_SCIM_CONFIG_PATH
 
 #include "scim_private.h"
@@ -57,25 +56,40 @@ enum Command
     DEL_KEY
 };
 
-String get_param_portion (const String &str)
+static String trim_blank (const String &str)
 {
-    String ret = str;
-    return (ret.erase (ret.find_first_of (" \t\n\v="), ret.length() - 1));
+    String::size_type begin, len;
+
+    begin = str.find_first_not_of (" \t\n\v");
+
+    if (begin == String::npos)
+        return String ();
+
+    len = str.find_last_not_of (" \t\n\v") - begin + 1;
+
+    return str.substr (begin, len);
 }
 
-String get_value_portion (const String &str)
+static String get_param_portion (const String &str)
 {
-    String ret = str;
-    ret.erase (0, ret.find_first_of ("=") + 1);
-    ret.erase (0, ret.find_first_not_of(" \n\t\v"));
-    return (ret.erase (ret.find_last_not_of(" \t\n\v") + 1));
+    String::size_type begin = str.find_first_of (" \t\n\v=");
+
+    if (begin == String::npos) return str;
+
+    return str.substr (0, begin);
 }
 
+static String get_value_portion (const String &str)
+{
+    String::size_type begin = str.find_first_of ("=");
+
+    if (begin == String::npos || (begin + 1) == str.length ()) return String ("");
+
+    return trim_blank (str.substr (begin + 1, String::npos));
+}
 
 int main (int argc, char *argv [])
 {
-    //FIXME
-    //If it's not static, then it will be crash with gconf config module.
     static ConfigModule  config_module;
 
     ConfigPointer        config;
@@ -83,13 +97,18 @@ int main (int argc, char *argv [])
     String               def_config;
     String               key;
     String               value;
+    String               display;
 
     DataType             type = DATA_TYPE_STRING;
     Command              cmd = DO_NOTHING;
-    String               app = String ("scim");
+    bool                 reload = false;
+    bool                 global = false;
 
     int                  i;
 
+    char *p =  getenv ("DISPLAY");
+    if (p) display = String (p);
+
     //get modules list
     scim_get_config_module_list (config_list);
 
@@ -122,8 +141,13 @@ int main (int argc, char *argv [])
                  << "                       string, int, double, bool, string-list,\n"
                  << "                       int-list. The default type is string.\n"
                  << "  -c, --config name    Use specified Config module,\n"
-                 << "  -a, --app name       The application's name, default is scim.\n"
                  << "                       use simple module by default.\n"
+                 << "                       Use \"global\" instead of a real config module name,\n"
+                 << "                       if you want to access the global configuration file.\n"
+                 << "                       (Normally they are /etc/scim/global and ~/.scim/global).\n"
+                 << "  --reload             Force the running scim to reload configuration.\n"
+                 << "  --display display    The display which scim Panel is running on,\n"
+                 << "                       it's only useful when --reload is used.\n"
                  << "  -h, --help           Show this help.\n";
             return 0;
         }
@@ -154,10 +178,13 @@ int main (int argc, char *argv [])
                 return -1;
             }
 
-            key = get_param_portion (String (argv [i]));
-            value = get_value_portion (String (argv [i]));
+            String str (argv [i]);
+            str = trim_blank (str);
 
-            if (!key.length () || !value.length ()) {
+            key = get_param_portion (str);
+            value = get_value_portion (str);
+
+            if (!key.length ()) {
                 cerr << "Bad argument for option " << argv [i-1] << endl;
                 return -1;
             }
@@ -217,13 +244,17 @@ int main (int argc, char *argv [])
             continue;
         }
 
-        if (String ("-a") == argv [i] ||
-            String ("--app") == argv [i]) {
+        if (String ("--display") == argv [i]) {
             if (++i >= argc) {
                 cerr << "No argument for option " << argv [i-1] << endl;
                 return -1;
             }
-            app = String (argv [i]);
+            display = String (argv [i]);
+            continue;
+        }
+
+        if (String ("--reload") == argv [i]) {
+            reload = true;
             continue;
         }
 
@@ -231,48 +262,86 @@ int main (int argc, char *argv [])
         return -1;
     }
 
-    if (cmd == DO_NOTHING || !key.length ()) {
+    if ((cmd == DO_NOTHING || !key.length ()) && reload == false) {
         cerr << "What do you want to do?\n";
         return -1;
     }
 
-    if (!config_module.load (def_config)) {
-        cerr << "Failed to load config module " << def_config << endl;
-        return -1;
-    }
-
-    config = config_module.create_config (app);
-
-    if (config.null ()) {
-        cerr << "Failed to create config object.\n";
-        return -1;
+    if (cmd != DO_NOTHING) {
+        if (def_config == "global") {
+            global = true;
+        } else {
+            if (!config_module.load (def_config)) {
+                cerr << "Failed to load config module " << def_config << endl;
+                return -1;
+            }
+ 
+            config = config_module.create_config ();
+ 
+            if (config.null ()) {
+                cerr << "Failed to create config object.\n";
+                return -1;
+            }
+        }
     }
 
     // Get data
     if (cmd == GET_DATA) {
         bool ok = false;
         if (type == DATA_TYPE_STRING) {
-            if ((ok = config->read (key, &value)) == true)
-                cout << value << endl;
+            if (global) {
+                value = scim_global_config_read (key, String (""));
+                ok = (scim_global_config_read (key, String ("Invalid")) == value);
+            } else {
+                ok = config->read (key, &value);
+            }
+            if (ok) cout << value << endl;
         } else if (type == DATA_TYPE_INT) {
             int intval;
-            if ((ok = config->read (key, &intval)) == true)
-                cout << intval << endl;
+            if (global) {
+                intval = scim_global_config_read (key, (int) 0); 
+                ok = (scim_global_config_read (key, (int) 0) == intval); 
+            } else {
+                ok = config->read (key, &intval);
+            }
+            if (ok) cout << intval << endl;
         } else if (type == DATA_TYPE_DOUBLE) {
             double doubleval;
-            if ((ok = config->read (key, &doubleval)) == true)
-                cout << doubleval << endl;
+            if (global) {
+                doubleval = scim_global_config_read (key, (double) 0);
+                ok = (scim_global_config_read (key, (double) 1) == doubleval);
+            } else {
+                ok = config->read (key, &doubleval);
+            }
+            if (ok) cout << doubleval << endl;
         } else if (type == DATA_TYPE_BOOL) {
             bool boolval;
-            if ((ok = config->read (key, &boolval)) == true)
-                cout << (boolval ? "true" : "false") << endl;
+            if (global) {
+                boolval = scim_global_config_read (key, (bool) false);
+                ok = (scim_global_config_read (key, (bool) true) == boolval);
+            } else {
+                ok = config->read (key, &boolval);
+            }
+            if (ok) cout << (boolval ? "true" : "false") << endl;
         } else if (type == DATA_TYPE_STRING_LIST) {
             std::vector <String> strlistval;
-            if ((ok = config->read (key, &strlistval)) == true)
-                cout << scim_combine_string_list (strlistval, ',') << endl;
+            if (global) {
+                strlistval = scim_global_config_read (key, strlistval);
+                ok = (strlistval.size () > 0);
+            } else {
+                ok = config->read (key, &strlistval);
+            }
+            if (ok) cout << scim_combine_string_list (strlistval, ',') << endl;
         } else if (type == DATA_TYPE_INT_LIST) {
             std::vector <int> intlistval;
-            if ((ok = config->read (key, &intlistval)) == true) {
+            if (global) {
+                intlistval = scim_global_config_read (key, intlistval);
+                ok = (intlistval.size () > 0);
+            } else {
+                ok = config->read (key, &intlistval);
+            }
+
+            if (ok) {
                 for (size_t i = 0; i<intlistval.size (); ++i) {
                     cout << intlistval [i];
                     if (i < intlistval.size () - 1)
@@ -291,52 +360,113 @@ int main (int argc, char *argv [])
     // Set data
     else if (cmd == SET_DATA) {
         bool ok = true;
-        if (type == DATA_TYPE_STRING) {
-            ok = config->write (key, value);
+        if (type != DATA_TYPE_STRING && !value.length ()) {
+            ok = false;
+        } else if (type == DATA_TYPE_STRING) {
+            if (global) {
+                scim_global_config_write (key, value);
+            } else {
+                ok = config->write (key, value);
+            }
         } else if (type == DATA_TYPE_INT) {
             int intval = strtol (value.c_str (), 0, 10);
-            ok = config->write (key, intval);
+            if (global) {
+                scim_global_config_write (key, intval);
+            } else {
+                ok = config->write (key, intval);
+            }
         } else if (type == DATA_TYPE_DOUBLE) {
             double doubleval = strtod (value.c_str (), 0);
-            ok = config->write (key, doubleval);
+            if (global) {
+                scim_global_config_write (key, doubleval);
+            } else {
+                ok = config->write (key, doubleval);
+            }
         } else if (type == DATA_TYPE_BOOL) {
             bool boolval = false;
             if (value == "true" || value == "True" || value == "TRUE" || value == "1")
                 boolval = true;
-            ok = config->write (key, boolval);
+
+            if (global) {
+                scim_global_config_write (key, boolval);
+            } else {
+                ok = config->write (key, boolval);
+            }
         } else if (type == DATA_TYPE_STRING_LIST) {
             std::vector <String> strlistval;
             scim_split_string_list (strlistval, value, ',');
-            ok = config->write (key, strlistval);
+
+            if (global) {
+                scim_global_config_write (key, strlistval);
+            } else {
+                ok = config->write (key, strlistval);
+            }
         } else if (type == DATA_TYPE_INT_LIST) {
             std::vector <int> intlistval;
             std::vector <String> strlist;
             scim_split_string_list (strlist, value, ',');
             for (size_t i = 0; i<strlist.size (); ++i)
                 intlistval.push_back (strtol (strlist[i].c_str (), 0, 10));
-            ok = config->write (key, intlistval);
+
+            if (global) {
+                scim_global_config_write (key, intlistval);
+            } else {
+                ok = config->write (key, intlistval);
+            }
         }
 
+        if (global)
+            ok = scim_global_config_flush ();
+
         if (!ok) {
-            cerr << "Failed to get key value.\n";
+            cerr << "Failed to set key value.\n";
             return -1;
         } else {
             cout << "Set data success.\n";
-            config->flush ();
+            if (!global) config->flush ();
         }
     }
 
     // Delete key
     else if (cmd == DEL_KEY) {
-        if (config->erase (key)) {
+        bool ok = false;
+
+        if (global) {
+            scim_global_config_reset (key); 
+            ok = scim_global_config_flush ();
+        } else {
+            ok = config->erase (key);
+        }
+
+        if (ok) {
             cout << "Delete key success.\n";
-            config->flush ();
+            if (!global) config->flush ();
         } else {
             cerr << "Failed to delete the key.\n";
             return -1;
         }
     }
 
+    if (reload) {
+        HelperInfo   helper_info ("41b79480-c5d2-4929-9456-11d519c26b87", "scim-config-agent", "", "", SCIM_HELPER_STAND_ALONE);
+        HelperAgent  helper_agent;
+
+        int          id;
+
+        id = helper_agent.open_connection (helper_info, display);
+
+        if (id < 0) {
+            cerr << "Unable to open the connection to scim Panel.\n";
+            return -1;
+        }
+
+        helper_agent.reload_config ();
+
+        cout << "Configuration reload request has been sent to the running scim.\n";
+
+        helper_agent.close_connection ();
+    }
+
     return 0;
 }
 
