@@ -1,7 +1,7 @@
 /*
  * Smart Common Input Method
  * 
- * Copyright (c) 2002 James Su <suzhe@turbolinux.com.cn>
+ * Copyright (c) 2002-2005 James Su <suzhe@tsinghua.org.cn>
  *
  *
  * This library is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_lookup_table.cpp,v 1.25 2004/06/15 04:31:11 suzhe Exp $
+ * $Id: scim_lookup_table.cpp,v 1.32 2005/05/13 04:21:29 suzhe Exp $
  *
  */
 
@@ -36,6 +36,7 @@ struct LookupTable::LookupTableImpl
     int                     m_current_page_start;
     int                     m_cursor_pos;
     bool                    m_cursor_visible;
+    bool                    m_page_size_fixed;
 
     std::vector<WideString> m_candidate_labels;
 
@@ -43,7 +44,8 @@ struct LookupTable::LookupTableImpl
         : m_page_size (page_size),
           m_current_page_start (0),
           m_cursor_pos (0),
-          m_cursor_visible (false) {
+          m_cursor_visible (false),
+          m_page_size_fixed (false) {
         if (m_page_size <= 0 || m_page_size > SCIM_LOOKUP_TABLE_MAX_PAGESIZE)
             m_page_size = SCIM_LOOKUP_TABLE_MAX_PAGESIZE;
     }
@@ -205,6 +207,18 @@ LookupTable::is_cursor_visible () const
     return m_impl->m_cursor_visible;
 }
 
+void
+LookupTable::fix_page_size (bool fixed)
+{
+    m_impl->m_page_size_fixed = fixed;
+}
+
+bool
+LookupTable::is_page_size_fixed () const
+{
+    return m_impl->m_page_size_fixed;
+}
+
 void
 LookupTable::set_cursor_pos (int pos)
 {
@@ -267,9 +281,19 @@ LookupTable::clear ()
     std::vector <int> ().swap (m_impl->m_page_history);
 }
 
+class CommonLookupTable::CommonLookupTableImpl
+{
+public:
+    std::vector <ucs4_t> m_buffer;
+    std::vector <uint32> m_index;
+
+    AttributeList        m_attributes;
+    std::vector <uint32> m_attrs_index;
+};
+
 //implementation of CommonLookupTable
 CommonLookupTable::CommonLookupTable (int page_size)
-    : LookupTable (page_size)
+    : LookupTable (page_size), m_impl (new CommonLookupTableImpl ())
 {
     std::vector <WideString> labels;
     char buf [2] = { 0, 0 };
@@ -277,23 +301,28 @@ CommonLookupTable::CommonLookupTable (int page_size)
         buf [0] = '1' + i;
         labels.push_back (utf8_mbstowcs (buf));
     }
-    buf [0] = '0';
-    labels.push_back (utf8_mbstowcs (buf));
+
+    labels.push_back (utf8_mbstowcs ("0"));
 
     set_candidate_labels (labels);
 }
 
 CommonLookupTable::CommonLookupTable (int                            page_size,
                                       const std::vector<WideString> &labels)
-    : LookupTable (page_size)
+    : LookupTable (page_size), m_impl (new CommonLookupTableImpl ())
 {
     set_candidate_labels (labels);
 }
 
+CommonLookupTable::~CommonLookupTable ()
+{
+    delete m_impl;
+}
+
 uint32
 CommonLookupTable::number_of_candidates () const
 {
-    return m_index.size ();
+    return m_impl->m_index.size ();
 }
 
 bool
@@ -303,13 +332,13 @@ CommonLookupTable::append_candidate (const WideString    &cand,
     if (cand.length () == 0)
         return false;
 
-    m_index.push_back (m_buffer.size ());
-    m_buffer.insert (m_buffer.end (), cand.begin (), cand.end ());
+    m_impl->m_index.push_back (m_impl->m_buffer.size ());
+    m_impl->m_buffer.insert (m_impl->m_buffer.end (), cand.begin (), cand.end ());
 
-    m_attrs_index.push_back (m_attributes.size ());
+    m_impl->m_attrs_index.push_back (m_impl->m_attributes.size ());
 
     if (attrs.size ())
-        m_attributes.insert (m_attributes.end (), attrs.begin (), attrs.end ());
+        m_impl->m_attributes.insert (m_impl->m_attributes.end (), attrs.begin (), attrs.end ());
 
     return true;
 }
@@ -321,13 +350,13 @@ CommonLookupTable::append_candidate (ucs4_t               cand,
     if (cand == 0)
         return false;
 
-    m_index.push_back (m_buffer.size ());
-    m_buffer.push_back (cand);
+    m_impl->m_index.push_back (m_impl->m_buffer.size ());
+    m_impl->m_buffer.push_back (cand);
 
-    m_attrs_index.push_back (m_attributes.size ());
+    m_impl->m_attrs_index.push_back (m_impl->m_attributes.size ());
 
     if (attrs.size ())
-        m_attributes.insert (m_attributes.end (), attrs.begin (), attrs.end ());
+        m_impl->m_attributes.insert (m_impl->m_attributes.end (), attrs.begin (), attrs.end ());
 
     return true;
 }
@@ -340,12 +369,12 @@ CommonLookupTable::get_candidate (int index) const
 
     std::vector <ucs4_t>::const_iterator start, end;
 
-    start = m_buffer.begin () + m_index [index];
+    start = m_impl->m_buffer.begin () + m_impl->m_index [index];
 
     if (index < number_of_candidates () - 1)
-        end = m_buffer.begin () + m_index [index+1];
+        end = m_impl->m_buffer.begin () + m_impl->m_index [index+1];
     else
-        end = m_buffer.end ();
+        end = m_impl->m_buffer.end ();
 
     return WideString (start, end);
 }
@@ -358,12 +387,12 @@ CommonLookupTable::get_attributes (int index) const
 
     AttributeList::const_iterator start, end;
 
-    start = m_attributes.begin () + m_attrs_index [index];
+    start = m_impl->m_attributes.begin () + m_impl->m_attrs_index [index];
 
     if (index < number_of_candidates () - 1)
-        end = m_attributes.begin () + m_attrs_index [index+1];
+        end = m_impl->m_attributes.begin () + m_impl->m_attrs_index [index+1];
     else
-        end = m_attributes.end ();
+        end = m_impl->m_attributes.end ();
 
     if (start < end)
         return AttributeList (start, end);
@@ -376,11 +405,11 @@ CommonLookupTable::clear ()
 {
     LookupTable::clear ();
 
-    std::vector <ucs4_t> ().swap (m_buffer);
-    std::vector <uint32> ().swap (m_index);
+    std::vector <ucs4_t> ().swap (m_impl->m_buffer);
+    std::vector <uint32> ().swap (m_impl->m_index);
 
-    AttributeList ().swap (m_attributes);
-    std::vector <uint32> ().swap (m_attrs_index);
+    AttributeList ().swap (m_impl->m_attributes);
+    std::vector <uint32> ().swap (m_impl->m_attrs_index);
 }
 
 } // namespace scim
